@@ -47,9 +47,9 @@
 
 ;;; Functions and literals have various MODE properties;;; >
 ;;; (at user level set up by $MODEDECLARE), such as "$FLOAT" and "$ANY".
-;;; The main problem solved by this translater (and the reason that
+;;; The main problem solved by this translator (and the reason that
 ;;; it works on forms from the "inside out" as an evaluator would do
-;;; (expect for macro forms)), is the problem of type (MODE) dependant
+;;; (expect for macro forms)), is the problem of type (MODE) dependent
 ;;; function calling and mode conversion. The function TRANSLATE
 ;;; returns a list  where the CAR of the list is the MODE of the
 ;;; expression and the CDR is the expression to be evaluated by
@@ -59,7 +59,7 @@
 ;;; of all its parts. See "*UNION-MODE"
 
 ;;; weak points in the code
-;;; [1] duplication of functionality in the translaters for
+;;; [1] duplication of functionality in the translators for
 ;;; MPLUS MTIMES etc. 
 ;;; [3] primitive mode scheme. lack of even the most primitive general
 ;;; type coercion code. Most FORTRAN compilers are better than this.
@@ -83,7 +83,7 @@
 ;;; frobs are seen outside of the functions. Note: this can be done
 ;;; simply by type coercion and operator folding.
 
-;;; General comments on the stucture of the code.
+;;; General comments on the structure of the code.
 ;;; A function named TR-<something> means that it translates
 ;;; something having to do with that something.
 ;;; N.B. It does not mean that that is the translate property for <something>.
@@ -170,7 +170,7 @@ GENERAL, the default gives code good for mexprs and mlexprs but not macros.
 GENERAL assures variable bindings are correct in compiled code.
 In GENERAL mode, when translating F(X), if F is a bound variable, then
 it assumes that APPLY(F,[X]) is meant, and translates a such, with 
-apropriate warning. There is no need to turn this off.
+appropriate warning. There is no need to turn this off.
 APPLY means like APPLY.")
 
 (defmvar $tr_array_as_ref t
@@ -236,7 +236,7 @@ APPLY means like APPLY.")
 ;;;     Undefined Variables ... same thing
 ;;;     Incomprehensible special forms
 ;;;     EV                      ....
-;;;     Predicate Mode Targetting failures.
+;;;     Predicate Mode Targeting failures.
 ;;;     .....  -gjc
 
 ;;; The way it works now is to print too little or too much.
@@ -522,7 +522,8 @@ APPLY means like APPLY.")
 
 
 (defun trfail (x)
-  (tr-format x (intl:gettext "error: failed to translate.~%")) nil)
+  (tr-format (intl:gettext "error: failed to translate ~:@M~%") x)
+  nil)
 
 (defmfun translate-and-eval-macsyma-expression (form)
   ;; this is the hyper-random entry to the transl package!
@@ -856,7 +857,7 @@ APPLY means like APPLY.")
 
 
 
-;;; Some atoms, soley by usage, are self evaluating. 
+;;; Some atoms, solely by usage, are self evaluating. 
 
 (defun implied-quotep (atom)
   (cond
@@ -872,7 +873,7 @@ APPLY means like APPLY.")
 	(t nil)))
 
 (defun translate-atoms (form)
-  ;; This is an oldy moldy which tries to declare everthing
+  ;; This is an oldy moldy which tries to declare everything
   ;; special so that calling fexpr's will work in compiled
   ;; code. What a joke.
   (cond ((atom form)
@@ -926,9 +927,6 @@ APPLY means like APPLY.")
   (setq tr-abort t)
   '($any . nil))
 
-(def%tr mdefine (form) ;; ((MDEFINE) ((F) ...) ...)
-  `($any . (meval ',form)))
-
 (def%tr mdefmacro (form)
   (meval form) ;; HMM, THIS HAS A SIDE EFFECT AT THE TIME OF TRANSLATION !!
   `($any . (meval ',form)))
@@ -971,7 +969,7 @@ APPLY means like APPLY.")
 	      (let* ((var (car l))
 		     (assign (get var 'assign)))
 		(if assign
-		    (cond ((member assign '(assign-mode-check) :test #'eq)
+		    (cond ((eq assign 'assign-mode-check)
 			   (push `(,assign ',var ,(teval var)) easy-assigns))
 			  (t
 			   (return nil)))))))
@@ -1224,11 +1222,9 @@ APPLY means like APPLY.")
 ;; The MDO and MDOIN translators should be changed to use the TR-LAMBDA.
 ;; Perhaps a mere expansion into an MPROG would be best.
 
-(declare-top (special shit))
-
 (def%tr mdo (form)
-  (let (returns assigns return-mode local (inside-mprog t) tem need-prog?)
-    (let (mode var init next test action varmode end-var init-end-var)
+  (let (returns assigns return-mode local (inside-mprog t) need-prog?)
+    (let (mode var init next test action varmode)
       (setq var (cond ((cadr form)) (t 'mdo)))
       (specialp var)
       (tbind var)
@@ -1241,7 +1237,6 @@ APPLY means like APPLY.")
       (setq form (copy-list form))
       ;;to make the end test for thru be numberp if the index is numberp
       ;;and to eliminate reevaluation
-      tem
       (cond ((not varmode)
 	     (declvalue var (*union-mode (car init) (car next)) t))
 	    (t
@@ -1254,25 +1249,16 @@ APPLY means like APPLY.")
 			       (list '(mlessp) var (cadr (cddddr form))))
 			      (t (list '(mgreaterp) var (cadr (cddddr form)))))
 			(caddr (cddddr form)))))
-      (cond ((and end-var (symbolp end-var)) (remprop end-var 'mode)
-	     (remprop end-var 'tbind)))
       (setq action (translate (cadddr (cddddr form)))
 	    mode (cond ((null returns) '$any)
-		       (t
-			(if shit
-			    (do ((l returns (cdr l))) ((null l))
-			      (rplaca (cdar l) (dconv (cadar l) return-mode))))
-			return-mode)))
+		       (t return-mode)))
       (setq var (tunbind (cond ((cadr form)) (t 'mdo))))
-      `(,mode do ((,var ,(cdr init) ,(cdr next))
-		  ,@ init-end-var )
+      `(,mode do ((,var ,(cdr init) ,(cdr next)))
 	      (,test '$done) . ((declare (special ,var)) .
 	      ,(cond ((atom (cdr action)) nil)
 		     ((eq 'progn (cadr action)) (cddr action))
 		     (t (list (cdr action)))))))))
 
-(setq shit nil)
-
 (def%tr mdoin (form)
   (let (returns assigns return-mode local (inside-mprog t) need-prog?)
     (prog (mode var init action)
@@ -1284,11 +1270,7 @@ APPLY means like APPLY.")
 	      (return `($any meval '((mdoin) . ,(cdr form))))))
        (setq action (translate (cadddr (cddddr form)))
 	     mode (cond ((null returns) '$any)
-			(t
-			 (if shit
-			     (do ((l returns (cdr l))) ((null l))
-			       (rplaca (cdar l) (dconv (cadar l) return-mode))))
-			 return-mode)))
+			(t return-mode)))
        (tunbind 'mdo) (tunbind (cadr form))
        (return
 	 `(,mode do ((,var) (mdo (cdr ,init) (cdr mdo)))
@@ -1339,11 +1321,6 @@ APPLY means like APPLY.")
 	   (setq val (translate val))
 	   `(,(car val) mset ',(translate-atoms var) ,(cdr val))))))
 
-(def%tr $rat (form)
-  (cond ((null (cddr form)) (cons '$cre (dconv-$cre (translate (cadr form)))))
-	(t (setq tr-abort t) (cons '$any form))))
-
-
 (def%tr $max (x) (translate-$max-$min x))
 (def%tr $min (x) (translate-$max-$min x))
 (def%tr %max (x) (translate-$max-$min x))
